@@ -36,7 +36,7 @@ ls_app.add_typer(controls_app, name="controls")
 
 def _print_list_of_guardrails(guardrail_list, header, do_print=True):
     """Prints the given list of GuardRail Controls."""
-    table = Table(title=f"[bold]{header}", title_style="white on black")
+    table = Table(title=f"[bold]{header}", title_style="black on white")
     table.add_column(
         "[bold]ControlTower GuardRail Identifiers",
         justify="left",
@@ -97,7 +97,7 @@ def _list_ous():
     if not organizational_units:
         raise typer.Exit("No organizational units found!")
 
-    table = Table(title=f"[bold]Organizational Units", title_style="white on black")
+    table = Table(title=f"[bold]Organizational Units", title_style="black on white")
     table.add_column("[bold]Name", justify="left", style="green", no_wrap=True)
     table.add_column("[bold]Identifier", justify="center", style="white", no_wrap=True)
     table.add_column("[bold]ARN", justify="center", style="cyan", no_wrap=True)
